@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 1998, 1999, 2000
+ * Copyright (c) 1997, 1998, 1999, 2000, 2001
  *      Inferno Nettverk A/S, Norway.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -32,8 +32,8 @@
  *  Software Distribution Coordinator  or  sdc@inet.no
  *  Inferno Nettverk A/S
  *  Oslo Research Park
- *  Gaustadalen 21
- *  N-0349 Oslo
+ *  Gaustadallen 21
+ *  NO-0349 Oslo
  *  Norway
  *
  * any improvements or extensions that they make and grant Inferno Nettverk A/S
@@ -51,7 +51,7 @@
 #endif  /* HAVE_STRVIS */
 
 static const char rcsid[] =
-"$Id: util.c,v 1.108 2000/11/21 09:20:54 michaels Exp $";
+"$Id: util.c,v 1.132 2002/01/02 14:30:23 michaels Exp $";
 
 /* fake "ip address", for clients without DNS access. */
 static char **ipv;
@@ -64,132 +64,6 @@ strcheck(string)
 	return string == NULL ? NOMEM : string;
 }
 
-char *
-sockshost2string(host, string, len)
-	const struct sockshost_t *host;
-	char *string;
-	size_t len;
-{
-
-	if (string == NULL) { /* to ease debugging. */
-		static char hstring[MAXSOCKSHOSTSTRING];
-
-		string = hstring;
-		len = sizeof(hstring);
-	}
-
-	switch (host->atype) {
-		case SOCKS_ADDR_IPV4:
-			snprintfn(string, len, "%s.%d",
-			inet_ntoa(host->addr.ipv4), ntohs(host->port));
-			break;
-
-		case SOCKS_ADDR_IPV6:
-				snprintfn(string, len, "%s.%d",
-				"<IPv6 address not supported>", ntohs(host->port));
-				break;
-
-		case SOCKS_ADDR_DOMAIN: {
-			char *name;
-
-			snprintfn(string, len, "%s.%d",
-			strcheck(name = str2vis(host->addr.domain, strlen(host->addr.domain))),
-			ntohs(host->port));
-			free(name);
-			break;
-		}
-
-		default:
-			SERRX(host->atype);
-	}
-
-	return string;
-}
-
-const char *
-command2string(command)
-	int command;
-{
-
-	switch (command) {
-		case SOCKS_BIND:
-			return SOCKS_BINDs;
-
-		case SOCKS_CONNECT:
-			return SOCKS_CONNECTs;
-
-		case SOCKS_UDPASSOCIATE:
-			return SOCKS_UDPASSOCIATEs;
-
-		/* pseudo commands. */
-		case SOCKS_ACCEPT:
-			return SOCKS_ACCEPTs;
-
-		case SOCKS_BINDREPLY:
-			return SOCKS_BINDREPLYs;
-
-		case SOCKS_UDPREPLY:
-			return SOCKS_UDPREPLYs;
-
-		case SOCKS_DISCONNECT:
-			return SOCKS_DISCONNECTs;
-
-		default:
-			SERRX(command);
-	}
-
-	/* NOTREACHED */
-}
-
-const char *
-method2string(method)
-	int method;
-{
-
-	switch (method) {
-		case AUTHMETHOD_NONE:
-			return AUTHMETHOD_NONEs;
-
-		case AUTHMETHOD_GSSAPI:
-			return AUTHMETHOD_GSSAPIs;
-
-		case AUTHMETHOD_UNAME:
-			return AUTHMETHOD_UNAMEs;
-
-		case AUTHMETHOD_NOACCEPT:
-			return AUTHMETHOD_NOACCEPTs;
-
-		case AUTHMETHOD_RFC931:
-			return AUTHMETHOD_RFC931s;
-
-		default:
-			SERRX(method);
-	}
-
-	/* NOTREACHED */
-}
-
-int
-string2method(methodname)
-	const char *methodname;
-{
-	struct {
-		char	*methodname;
-		int	method;
-	} method[] = {
-		{ AUTHMETHOD_NONEs,		AUTHMETHOD_NONE	},
-		{ AUTHMETHOD_UNAMEs,		AUTHMETHOD_UNAME	},
-		{ AUTHMETHOD_RFC931s,	AUTHMETHOD_RFC931	}
-	};
-	size_t i;
-
-	for (i = 0; i < ELEMENTS(method); ++i)
-		if (strcmp(method[i].methodname, methodname) == 0)
-			return method[i].method;
-
-	return -1;
-}
-
 unsigned char
 sockscode(version, code)
 	int version;
@@ -227,13 +101,14 @@ sockscode(version, code)
 					SERRX(code);
 			}
 			/* NOTREACHED */
-		
+
 		case HTTP_V1_0:
 			switch (code) {
 				case SOCKS_SUCCESS:
 					return HTTP_SUCCESS;
 
 				case SOCKS_FAILURE:
+					/* LINTED constant argument to NOT */
 					return !HTTP_SUCCESS;
 
 				default:
@@ -278,20 +153,25 @@ sockshost2sockaddr(host, addr)
 	struct sockaddr *addr;
 {
 	const char *function = "sockshost2sockaddr()";
+	uint8_t sa_len;
 
 	bzero(addr, sizeof(*addr));
-	/* LINTED pointer casts may be troublesome */
-	((struct sockaddr_in *)addr)->sin_family = AF_INET;
 
 	switch (host->atype) {
 		case SOCKS_ADDR_IPV4:
+			addr->sa_family = AF_INET;
+			sa_len = sizeof(struct sockaddr_in);
+
 			/* LINTED pointer casts may be troublesome */
-			((struct sockaddr_in *)addr)->sin_addr = host->addr.ipv4;
+			TOIN(addr)->sin_addr = host->addr.ipv4;
 			break;
 
 		case SOCKS_ADDR_DOMAIN: {
 			struct hostent *hostent;
 
+			addr->sa_family = AF_INET;
+			sa_len = sizeof(struct sockaddr_in);
+
 			if ((hostent = gethostbyname(host->addr.domain)) == NULL
 			||   hostent->h_addr_list == NULL) {
 				/* LINTED pointer casts may be troublesome */
@@ -299,14 +179,13 @@ sockshost2sockaddr(host, addr)
 				function, host->addr.domain, hstrerror(h_errno));
 
 				/* LINTED pointer casts may be troublesome */
-				((struct sockaddr_in *)addr)->sin_addr.s_addr = htonl(INADDR_ANY);
+				TOIN(addr)->sin_addr.s_addr = htonl(INADDR_ANY);
 
 				break;
 			}
 
 			/* LINTED pointer casts may be troublesome */
-			((struct sockaddr_in *)addr)->sin_addr
-			= *(struct in_addr *)(*hostent->h_addr_list);
+			TOIN(addr)->sin_addr = *(struct in_addr *)(*hostent->h_addr_list);
 
 			break;
 		}
@@ -314,10 +193,14 @@ sockshost2sockaddr(host, addr)
 		default:
 			SERRX(host->atype);
 	}
-	/* LINTED pointer casts may be troublesome */
-	((struct sockaddr_in *)addr)->sin_port = host->port;
+
+#if HAVE_SOCKADDR_SA_LEN
+	addr->sa_len = sa_len;
+#endif
 
 	/* LINTED pointer casts may be troublesome */
+	TOIN(addr)->sin_port = host->port;
+
 	return addr;
 }
 
@@ -327,32 +210,38 @@ fakesockshost2sockaddr(host, addr)
 	struct sockaddr *addr;
 {
 	const char *function = "fakesockshost2sockaddr()";
+	char string[MAXSOCKSHOSTSTRING];
+	uint8_t sa_len;
 
 #if SOCKS_CLIENT /* may be called before normal init, log to right place. */
 	clientinit();
 #endif
 
-	slog(LOG_DEBUG, "%s: %s", function, sockshost2string(host, NULL, 0));
+	slog(LOG_DEBUG, "%s: %s",
+	function, sockshost2string(host, string, sizeof(string)));
 
 	bzero(addr, sizeof(*addr));
-	/* LINTED pointer casts may be troublesome */
-	((struct sockaddr_in *)addr)->sin_family = AF_INET;
 
 	switch (host->atype) {
 		case SOCKS_ADDR_DOMAIN:
+			addr->sa_family = AF_INET;
+			sa_len = sizeof(struct sockaddr_in);
+
 			/* LINTED pointer casts may be troublesome */
-			if (socks_getfakeip(host->addr.domain,
-			&((struct sockaddr_in *)addr)->sin_addr)) {
-				/* LINTED pointer casts may be troublesome */
+			if (socks_getfakeip(host->addr.domain, &TOIN(addr)->sin_addr))
 				break;
-			}
 			/* else; */ /* FALLTHROUGH */
 
 		default:
 			return sockshost2sockaddr(host, addr);
 	}
+
+#if HAVE_SOCKADDR_SA_LEN
+	addr->sa_len = sa_len;
+#endif
+
 	/* LINTED pointer casts may be troublesome */
-	((struct sockaddr_in *)addr)->sin_port = host->port;
+	TOIN(addr)->sin_port = host->port;
 
 	return addr;
 }
@@ -367,9 +256,9 @@ sockaddr2sockshost(addr, host)
 		case AF_INET:
 			host->atype			= SOCKS_ADDR_IPV4;
 			/* LINTED pointer casts may be troublesome */
-			host->addr.ipv4	= ((const struct sockaddr_in *)addr)->sin_addr;
+			host->addr.ipv4	= TOCIN(addr)->sin_addr;
 			/* LINTED pointer casts may be troublesome */
-			host->port			= ((const struct sockaddr_in *)addr)->sin_port;
+			host->port			= TOCIN(addr)->sin_port;
 			break;
 
 		default:
@@ -379,110 +268,6 @@ sockaddr2sockshost(addr, host)
 	return host;
 }
 
-const char *
-operator2string(operator)
-	enum operator_t operator;
-{
-
-	switch (operator) {
-		case none:
-			return "none";
-
-		case eq:
-			return "eq";
-
-		case neq:
-			return "neq";
-
-		case ge:
-			return "ge";
-
-		case le:
-			return "le";
-
-		case gt:
-			return "gt";
-
-		case lt:
-			return "lt";
-
-		case range:
-			return "range";
-
-		default:
-			SERRX(operator);
-	}
-
-	/* NOTREACHED */
-}
-
-enum operator_t
-string2operator(string)
-	const char *string;
-{
-
-	if (strcmp(string, "eq") == 0 || strcmp(string, "=") == 0)
-		return eq;
-
-	if (strcmp(string, "neq") == 0 || strcmp(string, "!=") == 0)
-		return neq;
-
-	if (strcmp(string, "ge") == 0 || strcmp(string, ">=") == 0)
-		return ge;
-
-	if (strcmp(string, "le") == 0 || strcmp(string, "<=") == 0)
-		return le;
-
-	if (strcmp(string, "gt") == 0 || strcmp(string, ">") == 0)
-		return gt;
-
-	if (strcmp(string, "lt") == 0 || strcmp(string, "<") == 0)
-		return lt;
-
-	/* parser should make sure this never happens. */
-	SERRX(string);
-
-	/* NOTREACHED */
-}
-
-
-const char *
-ruleaddress2string(address, string, len)
-	const struct ruleaddress_t *address;
-	char *string;
-	size_t len;
-{
-
-	switch (address->atype) {
-		case SOCKS_ADDR_IPV4: {
-			char *a, *b;
-
-			snprintfn(string, len, "%s/%s, tcp port: %d, udp port: %d op: %s %d",
-			strcheck(a = strdup(inet_ntoa(address->addr.ipv4.ip))),
-			strcheck(b = strdup(inet_ntoa(address->addr.ipv4.mask))),
-			ntohs(address->port.tcp), ntohs(address->port.udp),
-			operator2string(address->operator),
-			ntohs(address->portend));
-			free(a);
-			free(b);
-			break;
-		}
-
-		case SOCKS_ADDR_DOMAIN:
-			snprintfn(string, len, "%s, tcp port: %d, udp port: %d op: %s %d",
-			address->addr.domain,
-			ntohs(address->port.tcp), ntohs(address->port.udp),
-			operator2string(address->operator),
-			ntohs(address->portend));
-			break;
-
-		default:
-			SERRX(address->atype);
-	}
-
-	return string;
-}
-
 struct sockshost_t *
 ruleaddress2sockshost(address, host, protocol)
 	const struct ruleaddress_t *address;
@@ -566,66 +351,67 @@ sockaddr2ruleaddress(addr, ruleaddr)
 	return ruleaddr;
 }
 
-const char *
-protocol2string(protocol)
-	int protocol;
+struct sockaddr *
+hostname2sockaddr(name, index, addr)
+	const char *name;
+	int index;
+	struct sockaddr *addr;
 {
-
-	switch (protocol) {
-		case SOCKS_TCP:
-			return PROTOCOL_TCPs;
-
-		case SOCKS_UDP:
-			return PROTOCOL_UDPs;
-
-		default:
-			SERRX(protocol);
-	}
-
-	/* NOTREACHED */
-}
+	struct hostent *hostent;
+	int i;
 
 
-char *
-sockaddr2string(address, string, len)
-	const struct sockaddr *address;
-	char *string;
-	size_t len;
-{
+	if ((hostent = gethostbyname(name)) == NULL)
+		return NULL;
 
-	if (string == NULL) {
-		static char addrstring[MAXSOCKADDRSTRING];
-
-		string = addrstring;
-		len = sizeof(addrstring);
-	}
-
-	switch (address->sa_family) {
-		case AF_UNIX: {
+	for (i = 0; hostent->h_addr_list[i] != NULL; ++i)
+		if (i == index) {
+			bzero(addr, sizeof(*addr));
+			addr->sa_family = (uint8_t)hostent->h_addrtype;
+#if HAVE_SOCKADDR_SA_LEN
+			addr->sa_len = hostent->h_length;
+#endif /* HAVE_SOCKADDR_SA_LEN */
+			SASSERTX(addr->sa_family == AF_INET);
 			/* LINTED pointer casts may be troublesome */
-			const struct sockaddr_un *addr = (const struct sockaddr_un *)address;
+			TOIN(addr)->sin_addr = *(struct in_addr *)hostent->h_addr_list[i];
+			/* LINTED pointer casts may be troublesome */
+			TOIN(addr)->sin_port = htons(0);
 
-			strncpy(string, addr->sun_path, len - 1);
-			string[len - 1] = NUL;
-			break;
+			return addr;
 		}
 
-		case AF_INET: {
-			/* LINTED pointer casts may be troublesome */
-			const struct sockaddr_in *addr = (const struct sockaddr_in *)address;
+	return NULL;
+}
 
-			snprintfn(string, len, "%s.%d",
-			inet_ntoa(addr->sin_addr), ntohs(addr->sin_port));
-			break;
+struct sockaddr *
+ifname2sockaddr(ifname, index, addr)
+	const char *ifname;
+	int index;
+	struct sockaddr *addr;
+{
+	int i;
+	struct ifaddrs ifa, *ifap = &ifa, *iface;
+
+	if (getifaddrs(&ifap) != 0)
+		return NULL;
+
+	for (iface = ifap, i = 0; i <= index && iface != NULL;
+	iface = iface->ifa_next)
+		if (strcmp(iface->ifa_name, ifname) == 0
+		&& iface->ifa_addr != NULL && iface->ifa_addr->sa_family == AF_INET) {
+			if (i++ != index)
+				continue;
+
+			*addr = *iface->ifa_addr;
+			freeifaddrs(ifap);
+			return addr;
 		}
 
-		default:
-			SERRX(address->sa_family);
-	}
-
-	return string;
+	freeifaddrs(ifap);
+	return NULL;
 }
 
+
 in_addr_t
 socks_addfakeip(host)
 	const char *host;
@@ -692,6 +478,7 @@ fakesockaddr2sockshost(addr, host)
 	struct sockshost_t *host;
 {
 	const char *function = "fakesockaddr2sockshost()";
+	char string[MAXSOCKADDRSTRING];
 
 #if SOCKS_CLIENT /* may be called before normal init, log to right place. */
 	clientinit();
@@ -699,17 +486,14 @@ fakesockaddr2sockshost(addr, host)
 
 	/* LINTED pointer casts may be troublesome */
 	slog(LOG_DEBUG, "%s: %s -> %s",
-	function, sockaddr2string(addr, NULL, 0),
-	socks_getfakehost(((const struct sockaddr_in *)addr)->sin_addr.s_addr)
-	== NULL ? sockaddr2string(addr, NULL, 0)
-	: socks_getfakehost(((const struct sockaddr_in *)addr)->sin_addr.s_addr));
+	function, sockaddr2string(addr, string, sizeof(string)),
+	socks_getfakehost(TOCIN(addr)->sin_addr.s_addr) == NULL ?
+	string : socks_getfakehost(TOCIN(addr)->sin_addr.s_addr));
 
 	/* LINTED pointer casts may be troublesome */
-	if (socks_getfakehost(((const struct sockaddr_in *)addr)->sin_addr.s_addr)
-	!= NULL) {
-		const char *ipname
+	if (socks_getfakehost(TOCIN(addr)->sin_addr.s_addr) != NULL) {
 		/* LINTED pointer casts may be troublesome */
-		= socks_getfakehost(((const struct sockaddr_in *)addr)->sin_addr.s_addr);
+		const char *ipname = socks_getfakehost(TOCIN(addr)->sin_addr.s_addr);
 
 		SASSERTX(ipname != NULL);
 
@@ -717,7 +501,7 @@ fakesockaddr2sockshost(addr, host)
 		SASSERTX(strlen(ipname) < sizeof(host->addr.domain));
 		strcpy(host->addr.domain, ipname);
 		/* LINTED pointer casts may be troublesome */
-		host->port	= ((const struct sockaddr_in *)addr)->sin_port;
+		host->port	= TOCIN(addr)->sin_port;
 	}
 	else
 		sockaddr2sockshost(addr, host);
@@ -725,84 +509,12 @@ fakesockaddr2sockshost(addr, host)
 	return host;
 }
 
-const char *
-socks_packet2string(packet, type)
-	  const void *packet;
-	  int type;
-{
-	static char buf[1024];
-	char hstring[MAXSOCKSHOSTSTRING];
-	unsigned char version;
-	const struct request_t *request = NULL;
-	const struct response_t *response = NULL;
-
-	switch (type) {
-		case SOCKS_REQUEST:
-			request = (const struct request_t *)packet;
-			version = request->version;
-			break;
-
-		case SOCKS_RESPONSE:
-			response = (const struct response_t *)packet;
-			version	= response->version;
-			break;
-
-	  default:
-		 SERRX(type);
-  }
-
-	switch (version) {
-		case SOCKS_V4:
-		case SOCKS_V4REPLY_VERSION:
-			switch (type) {
-				case SOCKS_REQUEST:
-					snprintfn(buf, sizeof(buf),
-					"(V4) VN: %d CD: %d address: %s",
-					request->version, request->command,
-					sockshost2string(&request->host, hstring, sizeof(hstring)));
-					break;
-
-				case SOCKS_RESPONSE:
-					snprintfn(buf, sizeof(buf), "(V4) VN: %d CD: %d address: %s",
-					response->version, response->reply,
-					sockshost2string(&response->host, hstring, sizeof(hstring)));
-					break;
-			}
-			break;
-
-		case SOCKS_V5:
-			switch (type) {
-				case SOCKS_REQUEST:
-					snprintfn(buf, sizeof(buf),
-					"VER: %d CMD: %d FLAG: %d ATYP: %d address: %s",
-					request->version, request->command, request->flag,
-					request->host.atype,
-					sockshost2string(&request->host, hstring, sizeof(hstring)));
-					break;
-
-				case SOCKS_RESPONSE:
-					snprintfn(buf, sizeof(buf),
-					"VER: %d REP: %d FLAG: %d ATYP: %d address: %s",
-					response->version, response->reply, response->flag,
-					response->host.atype,
-					sockshost2string(&response->host, hstring, sizeof(hstring)));
-					break;
-			}
-			break;
-
-		default:
-			SERRX(version);
-  }
-
-	return buf;
-}
-
 int
 socks_logmatch(d, log)
 	unsigned int d;
 	const struct logtype_t *log;
 {
-	int i;
+	size_t i;
 
 	for (i = 0; i < log->fpc; ++i)
 		if (d == (unsigned int)log->fplockv[i]
@@ -823,9 +535,9 @@ sockaddrareeq(a, b)
 	switch (a->sa_family) {
 		case AF_INET: {
 			/* LINTED pointer casts may be troublesome */
-			const struct sockaddr_in *in_a = (const struct sockaddr_in *)a;
+			const struct sockaddr_in *in_a = TOCIN(a);
 			/* LINTED pointer casts may be troublesome */
-			const struct sockaddr_in *in_b = (const struct sockaddr_in *)b;
+			const struct sockaddr_in *in_b = TOCIN(b);
 
 			if (in_a->sin_addr.s_addr != in_b->sin_addr.s_addr
 			||  in_a->sin_port		  != in_b->sin_port)
@@ -931,7 +643,7 @@ socketoptdup(s)
 {
 	const char *function = "socketoptdup()";
 	unsigned int i;
-	int flags, new_s;
+	int flags, new_s, errno_s;
 	socklen_t len;
 	union {
 		int					int_val;
@@ -1072,6 +784,8 @@ socketoptdup(s)
 
 	};
 
+	errno_s = errno;
+
 	len = sizeof(val);
 	if (getsockopt(s, SOL_SOCKET, SO_TYPE, &val, &len) == -1) {
 		swarn("%s: getsockopt(SO_TYPE)", function);
@@ -1109,6 +823,8 @@ socketoptdup(s)
 		swarn("%s: fcntl(F_GETFD/F_SETFD)", function);
 #endif
 
+	errno = errno_s;
+
 	return new_s;
 }
 
@@ -1181,17 +897,17 @@ socks_lock(descriptor, type, timeout)
 	int type;
 	int timeout;
 {
-/*	const char *function = "socks_lock()"; */
+	const char *function = "socks_lock()";
 	struct flock lock;
 	int rc;
 
+	SASSERTX(timeout <= 0);
+
 	lock.l_type		= (short)type;
 	lock.l_start	= 0;
 	lock.l_whence	= SEEK_SET;
 	lock.l_len		= 0;
 
-	SASSERTX(timeout <= 0);
-
 #if 0 /* missing some bits here to handle racecondition. */
 	if (timeout > 0) {
 		struct sigaction sigact;
@@ -1219,6 +935,7 @@ socks_lock(descriptor, type, timeout)
 	}
 #endif
 
+retry:
 	do
 		rc = fcntl(descriptor, timeout ? F_SETLKW : F_SETLK, &lock);
 	while (rc == -1 && timeout == -1 && errno == EINTR);
@@ -1231,8 +948,9 @@ socks_lock(descriptor, type, timeout)
 				break;
 
 			case ENOLCK:
+				swarn("%s: fcntl()", function);
 				sleep(1);
-				return socks_lock(descriptor, type, timeout);
+				goto retry; /* don't exhaust the stack by calling socks_lock(). */
 
 			default:
 				SERR(descriptor);
@@ -1297,9 +1015,8 @@ int
 fdisopen(fd)
 	int fd;
 {
-	if (fcntl(fd, F_GETFD, 0) == 0)
-		return 1;
-	return 0;
+
+	return fcntl(fd, F_GETFD, 0) != -1;
 }
 
 void
@@ -1334,7 +1051,7 @@ snprintfn(str, size, format, va_alist
 #else
 	va_start(ap);
 #endif  /* STDC_HEADERS */
-	
+
 	rc = vsnprintf(str, size, format, ap);
 
 	/* LINTED expression has null effect */
@@ -1347,3 +1064,20 @@ snprintfn(str, size, format, va_alist
 
 	return MIN(rc, (int)(size - 1));
 }
+
+/*
+ * Posted by Kien Ha (Kien_Ha@Mitel.COM) in comp.lang.c once upon a
+ * time.
+*/
+int
+bitcount(number)
+	unsigned long number;
+{
+	int bitsset;
+
+	for (bitsset = 0; number > 0; number >>= 1)
+		if (number & 1)
+			++bitsset;
+
+	return bitsset;
+}
