@@ -32,7 +32,7 @@
  *  Software Distribution Coordinator  or  sdc@inet.no
  *  Inferno Nettverk A/S
  *  Oslo Research Park
- *  Gaustadalllllen 21
+ *  Gaustadallen 21
  *  NO-0349 Oslo
  *  Norway
  *
@@ -44,7 +44,7 @@
 #include "common.h"
 
 static const char rcsid[] =
-"$Id: httpproxy.c,v 1.8 2001/02/06 15:58:55 michaels Exp $";
+"$Id: httpproxy.c,v 1.11 2001/12/12 14:42:11 karls Exp $";
 
 int
 httpproxy_negotiate(s, packet)
@@ -68,7 +68,7 @@ httpproxy_negotiate(s, packet)
 	 * with http's ':'.
 	*/
 	*strrchr(host, '.') = ':';
-	
+
 	len = snprintfn(buf, sizeof(buf),
 	"CONNECT %s HTTP/1.0\r\n"
 	"User-agent: %s/client v%s\r\n"
@@ -103,7 +103,7 @@ httpproxy_negotiate(s, packet)
 			buf[len] = NUL;
 		}
 
-		if ((eol = strstr(buf, terminator)) != NULL) { /* new line. */
+		while ((eol = strstr(buf, terminator)) != NULL) { /* new line. */
 			*eol = NUL;
 			slog(LOG_DEBUG, "%s: read: %s", function, buf);
 
@@ -116,7 +116,7 @@ httpproxy_negotiate(s, packet)
 
 						if (strncmp(buf, offset, strlen(offset)) != 0) {
 							error = 1;
-							break; 
+							break;
 						}
 
 						if (!isdigit(buf[strlen(offset)])) {
@@ -166,9 +166,10 @@ httpproxy_negotiate(s, packet)
 			buf[len] = NUL;
 
 			if (strncmp(buf, terminator, strlen(terminator)) == 0)
-				break;	/* empty line, all done. */
+				eof = 1;	/* empty line, all done. */
 		}
-		else if (eof) { /* won't get any new line, dump what we have. */
+
+		if (eof && !checked) { /* won't get any new line, dump what we have. */
 			slog(LOG_DEBUG, "%s: read: %s", function, buf);
 			len = 0;
 			buf[len] = 0;
