@@ -44,7 +44,7 @@
 #include "common.h"
 
 static const char rcsid[] =
-"$Id: method_uname.c,v 1.36 2001/02/06 15:59:04 michaels Exp $";
+"$Id: method_uname.c,v 1.38 2001/04/20 13:11:27 michaels Exp $";
 
 __BEGIN_DECLS
 
@@ -117,6 +117,7 @@ recv_ulen(s, request, state)
 	INIT(sizeof(*request->auth->mdata.uname.name));
 	CHECK(request->auth->mdata.uname.name, request->auth, NULL);
 
+	/* LINTED conversion from 'int' may lose accuracy */
 	OCTETIFY(*request->auth->mdata.uname.name);
 
 	state->rcurrent = recv_uname;
@@ -156,6 +157,7 @@ recv_plen(s, request, state)
 	INIT(sizeof(*request->auth->mdata.uname.password));
 	CHECK(request->auth->mdata.uname.password, request->auth, NULL);
 
+	/* LINTED conversion from 'int' may lose accuracy */
 	OCTETIFY(*request->auth->mdata.uname.password);
 
 	state->rcurrent = recv_passwd;
@@ -172,7 +174,6 @@ recv_passwd(s, request, state)
 {
 /*	const char *function = "recv_passwd()"; */
 	const size_t plen = (size_t)*request->auth->mdata.uname.password;
-	int status;
 	unsigned char response[1				/* version. */
 								+ 1				/* status.	*/
 	];
@@ -185,51 +186,18 @@ recv_passwd(s, request, state)
 	request->auth->mdata.uname.password + 1, plen);
 	request->auth->mdata.uname.password[plen] = NUL;
 
-	switch (status
-	= (unsigned char)passwordcheck((char *)request->auth->mdata.uname.name,
-	(char *)request->auth->mdata.uname.password)) {
-		case 0:
-			request->auth->matched = 1;
-			break; /* ok. */
-
-		case 1: {
-				char *name = (char *)request->auth->mdata.uname.name;
-
-				snprintfn(state->emsg, sizeof(state->emsg),
-				"denied access to non-existing user \"%s\"",
-				strcheck(name = str2vis(name, strlen(name))));
-				free(name);
-				break;
-		}
-
-		case 2: {
-				char *name = (char *)request->auth->mdata.uname.name;
-
-				snprintfn(state->emsg, sizeof(state->emsg),
-				"password authentication failed for user \"%s\"",
-				strcheck(name = str2vis(name, strlen(name))));
-				free(name);
-				break;
-		}
-
-		default:
-			SERRX(status);
-	}
-
-	bzero(request->auth->mdata.uname.password,
-	sizeof(request->auth->mdata.uname.password));
-
+	/*
+	 * Very sadly we can't do any checking of the username/password here since
+	 * we don't know what database to use, it depends on what the socks
+	 request is.
+	*/
 	response[UNAME_VERSION] = request->auth->mdata.uname.version;
-	response[UNAME_STATUS]	= (unsigned char)status;
+	response[UNAME_STATUS]	= (unsigned char)0;
 
-	if (writen(s, response, sizeof(response), request->auth) != sizeof(response))
+	if (writen(s, response, sizeof(response), request->auth)
+	!= sizeof(response))
 		return -1;
 
-	if (status == 0) {	/* 0 is success. */
-		state->rcurrent = recv_sockspacket;
-		return state->rcurrent(s, request, state);
-	}
-
-	errno = 0;
-	return -1;
+	state->rcurrent = recv_sockspacket;
+	return state->rcurrent(s, request, state);
 }
